@@ -1,9 +1,11 @@
-# coding=utf-8
+# -*- coding: utf8 -*-
+
 import os
-from pkg_resources import get_distribution, DistributionNotFound
 
 
 def get_dist():
+    from pkg_resources import get_distribution, DistributionNotFound
+
     dist = get_distribution('missinglink-kernel')
     # Normalize case for Windows systems
     dist_loc = os.path.normcase(dist.location)
@@ -17,6 +19,8 @@ def get_dist():
 
 
 def get_keywords():
+    from pkg_resources import DistributionNotFound
+
     try:
         dist = get_dist()
     except DistributionNotFound:
@@ -31,6 +35,8 @@ def get_keywords():
 
 
 def get_version():
+    from pkg_resources import DistributionNotFound
+
     try:
         dist = get_dist()
     except DistributionNotFound:
